@@ -1091,7 +1091,7 @@ do_des_decrypt( void *context, byte *outbuf, const byte *inbuf )
 gcry_cipher_spec_t _gcry_cipher_spec_des =
   {
     "DES", NULL, NULL, 8, 64, sizeof (struct _des_ctx),
-    do_des_setkey, do_des_encrypt, do_des_decrypt
+    do_des_setkey, do_des_encrypt, do_des_decrypt, NULL, NULL
   };
 
 static gcry_cipher_oid_spec_t oids_tripledes[] =
@@ -1107,5 +1107,6 @@ static gcry_cipher_oid_spec_t oids_tripledes[] =
 gcry_cipher_spec_t _gcry_cipher_spec_tripledes =
   {
     "3DES", NULL, oids_tripledes, 8, 192, sizeof (struct _tripledes_ctx),
-    do_tripledes_setkey, do_tripledes_encrypt, do_tripledes_decrypt
+    do_tripledes_setkey, do_tripledes_encrypt, do_tripledes_decrypt, 
+    NULL, NULL
   };
